package org.drools.reproducer;

import org.drools.compiler.kie.builder.impl.InternalKieModuleProvider;
import org.kie.api.KieServices;
import org.kie.api.builder.KieBuilder;
import org.kie.api.builder.KieFileSystem;
import org.kie.api.builder.KieModule;
import org.kie.api.builder.Message;
import org.kie.api.builder.ReleaseId;

public class KjarBuilder {

    private static final String DRL = "package org.drools.reproducer \n" +
            "\n" +
            "\n" +
            "\n" +
            "rule \"rule1\"\n" +
            "\n" +
            "when\n" +
            "\n" +
            "    m : String( toString() == \"Johnny\" )  \n" +
            "\n" +
            "then\n" +
            "\n" +
            "m = \"Rotten\";\n" +
            "\n" +
            "\n" +
            "\n" +
            "\n" +
            "\n" +
            "end";

    public KieModule build(String name, boolean executableModel) {
        return buildKieModule(name, "1.0", DRL, executableModel);
    }


    private static KieModule buildKieModule(String name, String version, String rules, boolean executableModel) {
        KieServices ks = KieServices.Factory.get();
        KieFileSystem kfs = ks.newKieFileSystem();

        ReleaseId rid = ks.newReleaseId("org.drools.reproducer", name, version);
        kfs.generateAndWritePomXML(rid);

        kfs.write("src/main/resources/org/drools/reproducer/rules.drl", rules);

        KieBuilder kb = ks.newKieBuilder(kfs);
        if (executableModel) {
            kb.buildAll(org.drools.modelcompiler.ExecutableModelProject.class);
        } else {
            kb.buildAll();
        }
        if (kb.getResults().hasMessages(Message.Level.ERROR)) {
            throw new RuntimeException("Build Errors:\n" + kb.getResults().toString());
        }

        return kb.getKieModule();
    }
}
