package org.drools.reproducer;

import javax.inject.Inject;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.asset.EmptyAsset;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.shrinkwrap.resolver.api.maven.Maven;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.kie.api.builder.KieModule;


@RunWith(Arquillian.class)
public class KjarBuilderTestIT {

    private static final String[] DEPENDENCIES = {
            "org.kie:kie-api:7.32.0.Final",
            "org.drools:drools-core:7.32.0.Final",
            "org.drools:drools-compiler:7.32.0.Final",
            "org.drools:drools-model-compiler:7.32.0.Final",
            "org.drools:drools-canonical-model:7.32.0.Final"
    };

    @Deployment
    public static WebArchive createDeployment() {
        WebArchive archive = ShrinkWrap.create(WebArchive.class)
                .addClass(KjarBuilder.class)
                .addAsWebInfResource(EmptyAsset.INSTANCE, "beans.xml")
                .addAsLibraries(Maven.resolver().resolve(DEPENDENCIES).withTransitivity().asFile());

        System.out.println(archive.toString(true));

        return archive;
    }

    @Inject
    KjarBuilder kjarBuilder;

    @Test
    public void buildKieModuleTestWithoutExecutableModel() {
        KieModule kieModule = kjarBuilder.build("test-without-executable-model", false);
        Assert.assertNotNull(kieModule);
    }

    @Test
    public void buildKieModuleTestWithExecutableModel() {
        KieModule kieModule = kjarBuilder.build("test-with-executable-model", true);
        Assert.assertNotNull(kieModule);
    }

}